# Generated by Django 2.2.26 on 2022-01-18 16:20

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('aimmo', '0027_add_game_data'),
    ]

    operations = [
        migrations.AlterField(
            model_name='game',
            name='game_class',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, to='common.Class', verbose_name='Class'),
        ),
    ]
